@@ -11,7 +11,8 @@
 double Estimator::prob_ltm(double theta, size_t question) {
     if(theta > 20.0 || theta < -20.0){
         std::string msg = "Theta value " + std::to_string(theta) + " too extreme for numerical routines to provide reliable calculations.  Try using less extreme values for theta.  If using MAP estimation, try EAP instead.";
-        throw std::domain_error(msg);
+        Rcpp::stop(msg);
+        //throw std::domain_error(msg);
     }
     
 	double eps = std::pow(std::pow(2.0, -52.0), 1.0/3.0);
@@ -85,12 +86,13 @@ std::vector<double> Estimator::prob_grm(double theta, size_t question) {
 
 	probabilities.push_back(1.0);
 
-// 	// checking for repeated elements
-//   	auto it = std::adjacent_find(probabilities.begin(), probabilities.end());
-//   	if(it != probabilities.end()){
-//   	    std::string msg = "Theta value " + std::to_string(theta) + " too extreme for numerical routines to provide reliable calculations.  Try using less extreme values for theta.  If using MAP estimation, try EAP instead.";
-//   	    throw std::domain_error(msg);
-//   	}
+	// checking for repeated elements
+  	auto it = std::adjacent_find(probabilities.begin(), probabilities.end());
+  	if(it != probabilities.end()){
+  	    std::string msg = "Theta value " + std::to_string(theta) + " too extreme for numerical routines to provide reliable calculations.  Try using less extreme values for theta.  If using MAP estimation, try EAP instead.";
+  	    Rcpp::stop(msg);
+  	    //throw std::domain_error(msg);
+  	}
 
 	return probabilities;
 }
@@ -121,12 +123,13 @@ std::pair<double,double> Estimator::prob_grm_pair(double theta, size_t question,
 		probs.second = calculate(difficulties[at-1]);
 	}
 
-// 	// checking for repeated elements
-//   	if(probs.first == probs.second)
-//   	{
-//   	    std::string msg = "Theta value " + std::to_string(theta) + " too extreme for numerical routines to provide reliable calculations.  Try using less extreme values for theta.  If using MAP estimation, try EAP instead.";
-//   	    throw std::domain_error(msg);
-//   	      	}
+	// checking for repeated elements
+  	if(probs.first == probs.second)
+  	{
+  	    std::string msg = "Theta value " + std::to_string(theta) + " too extreme for numerical routines to provide reliable calculations.  Try using less extreme values for theta.  If using MAP estimation, try EAP instead.";
+  	    Rcpp::stop(msg);
+  	    //throw std::domain_error(msg);
+  	      	}
 
 	return probs;
 }
@@ -155,7 +158,8 @@ std::vector<double> Estimator::prob_gpcm(double theta, size_t question) {
 	
 	if(denominator == 0.0 or std::isinf(denominator)){
 	    std::string msg = "Theta value " + std::to_string(theta) + " too extreme for numerical routines to provide reliable calculations.  Try using less extreme values for theta.  If using MAP estimation, try EAP instead.";
-	    throw std::domain_error(msg);
+	    Rcpp::stop(msg);
+	    //throw std::domain_error(msg);
   	}
 
   	// normalize
@@ -208,7 +212,8 @@ double Estimator::prob_gpcm_at(double theta, size_t question, size_t at)
 	
 	if(denominator == 0.0 or std::isinf(denominator)){
 	    std::string msg = "Theta value " + std::to_string(theta) + " too extreme for numerical routines to provide reliable calculations.  Try using less extreme values for theta.  If using MAP estimation, try EAP instead.";
-	    throw std::domain_error(msg);
+	    Rcpp::stop(msg);
+	    //throw std::domain_error(msg);
   	}
 
   	// normalize 
@@ -273,7 +278,8 @@ double Estimator::gpcm_partial_d1LL(double theta, size_t question, int answer) {
 
 	if(g == 0.0 or std::isinf(g)){
 	    std::string msg = "Theta value " + std::to_string(theta) + " too extreme for numerical routines to provide reliable calculations.  Try using less extreme values for theta.  If using MAP estimation, try EAP instead.";
-	    throw std::domain_error(msg);
+	    Rcpp::stop(msg);
+	    //throw std::domain_error(msg);
   	}
 
   	return (g*f_prime - f*g_prime)/(g*f);
@@ -349,7 +355,8 @@ double Estimator::gpcm_partial_d2LL(double theta, size_t question, int answer) {
 
 	if(g == 0.0 or std::isinf(g)){
 	    std::string msg = "Theta value " + std::to_string(theta) + " too extreme for numerical routines to provide reliable calculations.  Try using less extreme values for theta.  If using MAP estimation, try EAP instead.";
-	    throw std::domain_error(msg);
+	    Rcpp::stop(msg);
+	    //throw std::domain_error(msg);
   	}
 
 	double b = g*g;
@@ -461,7 +468,8 @@ void Estimator::prob_derivs_gpcm(double theta, size_t question, std::vector<doub
 
 std::vector<double> Estimator::probability(double theta, size_t question) {
   if (question > questionSet.answers.size() ) {
-    throw std::domain_error("Must use a question number applicable to Cat object.");
+      Rcpp::stop("Must use a question number applicable to Cat object.");
+    //throw std::domain_error("Must use a question number applicable to Cat object.");
   }
   
   	std::vector<double> probabilities;
